==> valknut-0.4.0a.tar.bz2: valknut-0.4.0a/valknut/about.h <==
QString g_sAboutAuthors = "\
<b>Developer</b><br><br>\
Mathias Kster<br>\
Core developer & maintainer<br><br>\
Stephen Leaf<br>\
Core developer<br><br>\
Jernej Simoncic<br>\
Developer & http-plugin maintainer<br><br>\
Franois Gannaz<br>\
Developer<br><br>\
Edward Sheldrake<br>\
Developer 0.3.8 and later<br><br>\
<b>Documentation</b><br><br>\
Andrew Greig<br>\
Doc writer<br><br>\
<b>Packagers</b><br><br>\
Ralph Slooten<br>\
<a href=\"http://axljab.homelinux.org/\">http://axljab.homelinux.org/</a><br>\
Mandrake packager<br><br>\
Philippe Lucas<br>\
<a href=\"http://perso.wanadoo.fr/philippe.lucas33/\">http://perso.wanadoo.fr/philippe.lucas33/</a><br>\
Mandrake packager<br><br>\
Pasi Savilaakso<br>\
Debian packager<br><br>\
Hanspeter Niederstrasser<br>\
<a href=\"http://snaggledworks.com/software/valknut/\">http://snaggledworks.com/software/valknut/</a><br>\
Mac OS X packager<br><br>\
<b>Logo</b><br><br>\
Frank Weiss<br>\
Version 0.1.X & 0.2.X<br><br>\
Gabe Gendreau<br>\
Version 0.3.x<br><br>\
\
<b>Translators</b><br>\
<br>\
\
<u>Bosnian translation</u><br>\
<br>\
Adis Beglerovic<br>\
<br>\
\
<u>Czech translation</u><br>\
<br>\
Jan Navratil<br>\
Radek Vybral<br>\
<br>\
\
<u>Danish translation</u><br>\
<br>\
Jack Joergensen<br>\
<br>\
\
<u>German translation</u><br>\
<br>\
Matthias Krger<br>\
Mathias Kster<br>\
<br>\
\
<u>Greek translation</u><br>\
<br>\
Chris Maltezos<br>\
<br>\
\
<u>Spanish translation</u><br>\
<br>\
Juan Pablo Feria Gomez<br>\
Juan Martin<br>\
<br>\
\
<u>Finnish translation</u><br>\
<br>\
Pasi Savilaakso<br>\
<br>\
\
<u>French translation</u><br>\
<br>\
Lionel Van Winnendaele<br>\
Damien Cassou<br>\
Lucas Philippe<br>\
<br>\
\
<u>Hungarian translation</u><br>\
<br>\
Kapcsandi Istvan<br>\
Farkas Barnabs<br>\
<br>\
\
<u>Icelandic translation</u><br>\
<br>\
Frijn Gujohnsen<br>\
<br>\
\
<u>Italian translation</u><br>\
<br>\
Alessandro De Maria<br>\
Davide Lemma<br>\
<br>\
\
<u>Latvian translation</u><br>\
<br>\
Maris Paupe<br>\
<br>\
\
<u>Norwegian translation</u><br>\
<br>\
yvind Sther<br>\
Stian Hole<br>\
<br>\
\
<u>Dutch translation</u><br>\
<br>\
Tom Verschueren<br>\
<br>\
\
<u>Polish translation</u><br>\
<br>\
Cezary Biele<br>\
<br>\
\
<u>Brazilian Portuguese translation</u><br>\
<br>\
Andr Luiz<br>\
<br>\
\
<u>Romanian translation</u><br>\
<br>\
Radu Dineiu<br>\
<br>\
\
<u>Russian translation</u><br>\
<br>\
Stan Novogorudski<br>\
Ilya Kurikhin (updated for 0.3.12)<br>\
<br>\
\
<u>Slovakian translation</u><br>\
<br>\
Jozef Riha<br>\
<br>\
\
<u>Swedish translation</u><br>\
<br>\
Henrik Sankala<br>\
Boban Jelica<br>\
Erik Englund<br>\
<br>\
";

==> valknut-0.4.4.tar.bz2: valknut-0.4.4/valknut/about.h <==
QString g_sAboutAuthors = "\
<b>Developer</b><br><br>\
Mathias Kster<br>\
Core developer & maintainer<br><br>\
Stephen Leaf<br>\
Core developer<br><br>\
Jernej Simoncic<br>\
Developer & http-plugin maintainer<br><br>\
Franois Gannaz<br>\
Developer<br><br>\
Edward Sheldrake<br>\
Developer 0.3.8 and later<br><br>\
<b>Documentation</b><br><br>\
Andrew Greig<br>\
Doc writer<br><br>\
<b>Packagers</b><br><br>\
Ralph Slooten<br>\
<a href=\"http://axljab.homelinux.org/\">http://axljab.homelinux.org/</a><br>\
Mandrake packager<br><br>\
Philippe Lucas<br>\
<a href=\"http://perso.wanadoo.fr/philippe.lucas33/\">http://perso.wanadoo.fr/philippe.lucas33/</a><br>\
Mandrake packager<br><br>\
Pasi Savilaakso<br>\
Debian packager<br><br>\
Hanspeter Niederstrasser<br>\
<a href=\"http://snaggledworks.com/software/valknut/\">http://snaggledworks.com/software/valknut/</a><br>\
Mac OS X packager<br><br>\
<b>Logo</b><br><br>\
Frank Weiss<br>\
Version 0.1.X & 0.2.X<br><br>\
Gabe Gendreau<br>\
Version 0.3.x<br><br>\
\
<b>Translators</b><br>\
<br>\
\
<u>Bosnian translation</u><br>\
<br>\
Adis Beglerovic<br>\
<br>\
\
<u>Czech translation</u><br>\
<br>\
Jan Navratil<br>\
Radek Vybral<br>\
<br>\
\
<u>Danish translation</u><br>\
<br>\
Jack Joergensen<br>\
<br>\
\
<u>German translation</u><br>\
<br>\
Matthias Krger<br>\
Mathias Kster<br>\
<br>\
\
<u>Greek translation</u><br>\
<br>\
Chris Maltezos<br>\
<br>\
\
<u>Spanish translation</u><br>\
<br>\
Juan Pablo Feria Gomez<br>\
Juan Martin<br>\
<br>\
\
<u>Finnish translation</u><br>\
<br>\
Pasi Savilaakso<br>\
<br>\
\
<u>French translation</u><br>\
<br>\
Lionel Van Winnendaele<br>\
Damien Cassou<br>\
Lucas Philippe<br>\
<br>\
\
<u>Hungarian translation</u><br>\
<br>\
Kapcsandi Istvan<br>\
Farkas Barnabs<br>\
sourceforge user osod88 (for 0.3.14 and later)<br>\
<br>\
\
<u>Icelandic translation</u><br>\
<br>\
Frijn Gujohnsen<br>\
<br>\
\
<u>Italian translation</u><br>\
<br>\
Alessandro De Maria<br>\
Davide Lemma<br>\
<br>\
\
<u>Latvian translation</u><br>\
<br>\
Maris Paupe<br>\
<br>\
\
<u>Norwegian translation</u><br>\
<br>\
yvind Sther<br>\
Stian Hole<br>\
<br>\
\
<u>Dutch translation</u><br>\
<br>\
Tom Verschueren<br>\
<br>\
\
<u>Polish translation</u><br>\
<br>\
Cezary Biele<br>\
Mateusz Kurtas (for 0.3.14 and later)<br>\
<br>\
\
<u>Brazilian Portuguese translation</u><br>\
<br>\
Andr Luiz<br>\
<br>\
\
<u>Romanian translation</u><br>\
<br>\
Radu Dineiu<br>\
<br>\
\
<u>Russian translation</u><br>\
<br>\
Stan Novogorudski<br>\
Ilya Kurikhin (for 0.3.12 and later)<br>\
<br>\
\
<u>Slovakian translation</u><br>\
<br>\
Jozef Riha<br>\
<br>\
\
<u>Swedish translation</u><br>\
<br>\
Henrik Sankala<br>\
Boban Jelica<br>\
Erik Englund<br>\
<br>\
\
<u>Serbian translation</u><br>\
<br>\
Urosevic Aleksandar<br>\
<br>\
";
